==> senior_authentication-0.3.1.tar.gz: lib/src/screens/username/bloc/username_bloc.dart <==
import 'package:equatable/equatable.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:senior_authentication/senior_authentication.dart';
import 'package:senior_authentication/src/utils/exceptions.dart';
import './username_form_state.dart';

part 'username_event.dart';
part 'username_state.dart';

class UsernameBloc extends Bloc<UsernameEvent, UsernameState> {
  final AuthenticationRepository authenticationRepository;

  UsernameBloc({required this.authenticationRepository}) : super(const UsernameState()) {
    on<UsernameChanged>((event, emit) {
      emit(state.copyWith(username: event.username, formState: const UsernameFormInitial()));
    });

    on<UsernameSubmitted>((event, emit) async {
      emit(state.copyWith(formState: UsernameFormLoadInProgress()));

      try {
        var domain = state.username.split('@')[1];
        var tenantLoginSettings = await authenticationRepository.getTenantLogInSettings(domain, null);

        emit(
          state.copyWith(
            formState: UsernameFormLoadSuccess(username: state.username, tenantLoginSettings: tenantLoginSettings),
          ),
        );
      } on TenantLogInSettingsIncorrect catch (_) {
        final exception = FormatException(
          'Ocorreu um erro ao localizar as configurações do e-mail informado. Verifique se você usou o mesmo e-mail que utilizada para se conectar na Plataforma Senior X.',
        );
        emit(state.copyWith(
          formState: UsernameFormLoadFailure(exception),
        ));
      } catch (_) {
        final exception = FormatException(
          'Ocorreu um erro ao verificar as informações do e-mail. Por favor, tente novamente mais tarde.',
        );
        emit(state.copyWith(
          formState: UsernameFormLoadFailure(exception),
        ));
      }
    });
  }
}

==> senior_authentication-0.3.3.tar.gz: lib/src/screens/username/bloc/username_bloc.dart <==
import 'package:equatable/equatable.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:senior_authentication/senior_authentication.dart';
import 'package:senior_authentication/src/utils/exceptions.dart';
import './username_form_state.dart';

part 'username_event.dart';
part 'username_state.dart';

class UsernameBloc extends Bloc<UsernameEvent, UsernameState> {
  final AuthenticationRepository authenticationRepository;

  UsernameBloc({required this.authenticationRepository}) : super(const UsernameState()) {
    on<UsernameChanged>((event, emit) {
      emit(state.copyWith(username: event.username, formState: const UsernameFormInitial()));
    });

    on<UsernameSubmitted>((event, emit) async {
      emit(state.copyWith(formState: UsernameFormLoadInProgress()));

      try {
        var domain = state.username.split('@')[1];
        var tenantLoginSettings = await authenticationRepository.getTenantLogInSettings(domain, null);

        emit(
          state.copyWith(
            formState: UsernameFormLoadSuccess(username: state.username, tenantLoginSettings: tenantLoginSettings),
          ),
        );
      } on TenantLogInSettingsIncorrect catch (_) {
        final exception = FormatException(
          'Ocorreu um erro ao localizar as configurações do e-mail informado. Verifique se você usou o mesmo e-mail que utiliza para se conectar na Plataforma Senior X.',
        );
        emit(state.copyWith(
          formState: UsernameFormLoadFailure(exception),
        ));
      } catch (_) {
        final exception = FormatException(
          'Ocorreu um erro ao verificar as informações do e-mail. Por favor, tente novamente mais tarde.',
        );
        emit(state.copyWith(
          formState: UsernameFormLoadFailure(exception),
        ));
      }
    });
  }
}
